<?php
/**
 * Template part for displaying front page features.
 *
 * @package Moral
 */

// Get default  mods value.
$features = get_theme_mod( 'kyamera_pro_features', 'custom' );

if ( 'disable' === $features ) {
    return;
}

$default = kyamera_pro_get_default_mods();

$features_num = get_theme_mod( 'kyamera_pro_features_num', 3 );

$col_class = '';
if ( $features_num > 4 ) {
    if ( $features_num % 3 === 0 ) {
        $col_class = 3;
    } else {
        $col_class = 4;
    }
} else {
    $col_class = $features_num;
}
$section_title = get_theme_mod( 'kyamera_pro_features_section_title', $default['kyamera_pro_features_section_title'] );
$btn_url     = get_theme_mod( 'kyamera_pro_features_link' );
$btn_txt = get_theme_mod( 'kyamera_pro_features_btn_txt', $default['kyamera_pro_features_btn_txt'] );


?>
<div id="our-features" class="relative page-section same-background">
    <div class="wrapper">
        <?php if (!empty($section_title)) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>
        <div class=" col-<?php echo esc_attr( $col_class ); ?> clear ">
                <?php

                if (  in_array( $features, array( 'post', 'page', 'cat' ) ) ) {

                    if ( 'cat' === $features ) {
                        $cat_id = get_theme_mod( 'kyamera_pro_features_cat' );
                        $args = array(
                            'cat' => $cat_id,   
                            'posts_per_page' =>  absint( $features_num ),
                        );
                    } else {
                        $id = array();
                        for ( $i=1; $i <= $features_num; $i++ ) { 
                            $id[] = get_theme_mod( "kyamera_pro_features_{$features}_" . $i );
                        }
                        $args = array(
                            'post_type' => $features,
                            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
                            'posts_per_page' => absint( $features_num ),
                            'ignore_sticky_posts' => true,
                        );
                    }

                    $query = new WP_Query( $args );

                    $i = 1;
                    if ( $query->have_posts() ) :
                        while ( $query->have_posts() ) :
                            $query->the_post();
                            $features_icon = get_theme_mod( 'kyamera_pro_features_icons_'. $i);
                            ?>

                            <article>
                                <div class="featured-item-wrapper">
                                    <?php if (!empty($features_icon)) : ?>
                                        <div class="feature-icon">
                                            <a href="<?php the_permalink(); ?>"><i class="fa <?php echo esc_attr($features_icon); ?>"></i></a>
                                        </div><!-- .feature-icon -->
                                    <?php endif; ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <?php $content = get_the_content();
                                        echo wp_trim_words( $content, 20); ?>
                                    </div><!-- .entry-content -->
                                </div><!-- .featured-item-wrapper -->
                            </article>
                        <?php 
                        $i++;
                        endwhile;
                        wp_reset_postdata();
                    endif; 
                } else{
                    for ( $i=1; $i <= $features_num; $i++ ) { 
                        $title   = get_theme_mod( 'kyamera_pro_features_custom_title_' . $i, $default['kyamera_pro_features_custom_title'] );
                        $excerpt   = get_theme_mod( 'kyamera_pro_features_custom_content_' . $i, $default['kyamera_pro_features_custom_content'] );
                        $url   = get_theme_mod( 'kyamera_pro_features_link_' . $i, '#' );
                        $features_icon = get_theme_mod( 'kyamera_pro_features_icons_'. $i);
                        ?>
                        <article>
                            <div class="featured-item-wrapper">
                                <?php if (!empty($features_icon)) : ?>
                                    <div class="feature-icon">
                                        <a href="<?php echo esc_url($url); ?>"><i class="fa <?php echo esc_attr($features_icon); ?>"></i></a>
                                    </div><!-- .feature-icon -->
                                <?php endif; ?>

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($url); ?>"><?php echo esc_html($title); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <?php echo wp_kses_post($excerpt); ?>
                                </div><!-- .entry-content -->
                            </div><!-- .featured-item-wrapper -->
                        </article>
                <?php   
                    }
                }
                ?>
                
        </div><!-- .features-items-wrapper -->
        <?php if ((!empty($btn_txt)) && (!empty($btn_url))) : ?>
            <div class="view-all">
                <a href="<?php echo esc_url($btn_url); ?>" class="btn"><?php echo esc_html($btn_txt); ?></a>
            </div><!-- .view-all -->
        <?php endif; ?>
    </div><!-- .wrapper -->
</div><!-- #features-section -->
