<?php
/**
 * Template part for displaying front page gallery.
 *
 * @package Moral
 */

// Get default  mods value.
$gallery = get_theme_mod( 'kyamera_pro_gallery', 'custom' );

if ( 'disable' === $gallery ) {
    return;
}

$default = kyamera_pro_get_default_mods();

$gallery_num = get_theme_mod( 'kyamera_pro_gallery_num', 3 );

$section_title = get_theme_mod( 'kyamera_pro_gallery_section_title', $default['kyamera_pro_gallery_section_title'] );
$btn_url     = get_theme_mod( 'kyamera_pro_gallery_link','#' );
$btn_txt = get_theme_mod( 'kyamera_pro_gallery_btn_txt', $default['kyamera_pro_gallery_btn_txt'] );


?>
<div id="photo-gallery" class="relative page-section same-background">
    <div class="wrapper">
        <?php if (!empty($section_title)) : ?>
            <div class="section-header">
                <h2 class="section-title"><?php echo esc_html( $section_title ); ?></h2>
            </div><!-- .section-header -->
        <?php endif; ?>
        <div class=" col-2 clear">
                <?php

                if (  in_array( $gallery, array( 'post', 'page', 'cat' ) ) ) {

                    if ( 'cat' === $gallery ) {
                        $cat_id = get_theme_mod( 'kyamera_pro_gallery_cat' );
                        $args = array(
                            'cat' => $cat_id,   
                            'posts_per_page' =>  absint( $gallery_num ),
                        );
                    } else {
                        $id = array();
                        for ( $i=1; $i <= $gallery_num; $i++ ) { 
                            $id[] = get_theme_mod( "kyamera_pro_gallery_{$gallery}_" . $i );
                        }
                        $args = array(
                            'post_type' => $gallery,
                            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
                            'posts_per_page' => absint( $gallery_num ),
                            'ignore_sticky_posts' => true,
                        );
                    }

                    $query = new WP_Query( $args );

                    $i = 1;
                    if ( $query->have_posts() ) :
                        while ( $query->have_posts() ) :
                            $query->the_post();                            
                            ?>
                            <article>
                                <div class="gallery-item-wrapper">
                                    <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url( 'large' );?>');">
                                        <a href="<?php the_permalink(); ?>" class="post-thumbnail-link"></a>
                                        <div class="overlay"></div>
                                        <div class="entry-container">
                                            <div class="gallery-info">
                                            <?php
                                                        $author_img = get_avatar_url( get_the_author_meta( 'ID' ));
                                                     ?>
                                                <div class="author-image" style="background-image: url('<?php echo esc_url( $author_img ); ?>');">
                                                    <a href="<?php esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) )) ; ?>" class="post-thumbnail-link"></a>
                                                </div><!-- .author-image -->
                                                
                                                <div class="gallery-content">
                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
                                                    </header>
                                                    <span class="cat-links">
                                                       <?php the_category(); ?>
                                                    </span><!-- .cat-links -->
                                                </div><!-- .gallery-content -->
                                            </div><!-- .gallery-info -->
                                        </div><!-- .entry-container -->
                                    </div><!-- .featured-image -->

                                </div><!-- .gallery-item-wrapper -->
                            </article>
                        <?php 
                        $i++;
                        endwhile;
                        wp_reset_postdata();
                    endif; 
                } else{
                    for ( $i=1; $i <= $gallery_num; $i++ ) { 
                        $title   = get_theme_mod( 'kyamera_pro_gallery_custom_title_' . $i, $default['kyamera_pro_gallery_custom_title'] );
                        $subtitle   = get_theme_mod( 'kyamera_pro_gallery_custom_subtitle_' . $i, $default['kyamera_pro_gallery_custom_subtitle'] );
                        $url   = get_theme_mod( 'kyamera_pro_gallery_custom_link_' . $i, '#' );
                        $gallery_image = get_theme_mod( 'kyamera_pro_gallery_custom_image_'. $i);
                        ?>
                        <article>
                            <div class="gallery-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $gallery_image );?>');">
                                    <a href="<?php echo esc_url($url); ?>" class="post-thumbnail-link"></a>
                                    <div class="overlay"></div>
                                    <div class="entry-container">
                                        <div class="gallery-info">
                                            <div class="gallery-content">
                                                <?php if (!empty($title)): ?>
                                                    <header class="entry-header">
                                                        <h2 class="entry-title"><a href="<?php echo esc_url($url); ?>"><?php echo esc_html($title); ?></a></h2>
                                                    </header>
                                                <?php endif ?>
                                                <?php if (!empty($subtitle)): ?>
                                                    <span class="cat-links">
                                                        <ul class="post-categories">
                                                            <li><a href="#"><?php echo esc_html($subtitle); ?></a></li>
                                                        </ul>
                                                    </span><!-- .cat-links -->
                                                <?php endif ?>
                                            </div><!-- .gallery-content -->
                                        </div><!-- .gallery-info -->
                                    </div><!-- .entry-container -->
                                </div><!-- .featured-image -->

                            </div><!-- .gallery-item-wrapper -->
                        </article>
                <?php   
                    }
                } ?>
            </div><!-- .gallery-items-wrapper -->
            <?php if ( ( !empty( $btn_txt ) ) && ( !empty( $btn_url ) ) ) :  ?>
            <div class="view-all">
                <a href="<?php echo esc_url($btn_url); ?>" class="btn"><?php echo esc_html($btn_txt); ?></a>
            </div>
            <?php endif; ?>
    </div><!-- .wrapper -->
</div><!-- #gallery-section -->