<?php
/**
 * Template part for displaying front page testimonial.
 *
 * @package Moral
 */

// Get default  mods value.
$testimonial = get_theme_mod( 'kyamera_pro_testimonial', 'custom' );

if ( 'disable' === $testimonial ) {
    return;
}

$default = kyamera_pro_get_default_mods();

$testimonial_num = get_theme_mod( 'kyamera_pro_testimonial_num', 3 );

$testimonial_background = get_theme_mod( 'kyamera_pro_testimonial_background');

?>
<div id="testimonial-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $testimonial_background); ?>');" >
	<div class="overlay"></div>
    <div class="wrapper">
        <div class="testimonial-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": false, "arrows":true, "autoplay": true, "fade": true }'>
	        	<?php

	        	if (  in_array( $testimonial, array( 'post', 'page', 'cat' ) ) ) {

	        	    if ( 'cat' === $testimonial ) {
	        	        $cat_id = get_theme_mod( 'kyamera_pro_testimonial_cat' );
	        	        $args = array(
	        	            'cat' => $cat_id,   
	        	            'posts_per_page' => absint( $testimonial_num ),
	        	        );
	        	    } else {
	        	        $id = array();
	        	        for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	            $id[] = get_theme_mod( "kyamera_pro_testimonial_{$testimonial}_" . $i );
	        	        }
	        	        $args = array(
	        	            'post_type' => $testimonial,
	        	            'post__in' => (array)$id,   
                            'orderby'   => 'post__in',
	        	            'posts_per_page' => absint( $testimonial_num ),
	        	            'ignore_sticky_posts' => true,
	        	        );
	        	    }

	        	    $query = new WP_Query( $args );
	        	    $i = 1;
	        	    if ( $query->have_posts() ) :
	        	        while ( $query->have_posts() ) :
	        	            $query->the_post();

	        	            $class = ( has_post_thumbnail() ) ? 'has-featured-image' : '';
	        	            ?>
	        	        	
	        	        	<article>
	                            <div class="featured-image" style="background-image: url('<?php the_post_thumbnail_url() ?>');">
	                                <a href="<?php the_permalink(); ?>" class="post-thumbnail-link"></a>
	                            </div><!-- .featured-image -->

	                            <div class="entry-content">
	                                <?php $content = get_the_content();
                                        echo wp_trim_words( $content, 30); ?>
	                            </div><!-- .entry-content -->
	                            <?php $position = get_theme_mod( 'kyamera_pro_testimonial_position_'. $i ); ?>
	                            <header class="entry-header">
	                                <h2 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h2>
	                                <p class="position"><?php echo esc_html($position); ?></p>
	                            </header>
                        	</article>
	        	        <?php 
	        	        $i++;
	        	    	endwhile;
	        	        wp_reset_postdata();
	        	    endif; 
	        	} else {
	        	    for ( $i=1; $i <= $testimonial_num; $i++ ) { 
	        	        $title   = get_theme_mod( 'kyamera_pro_testimonial_custom_name_' . $i, $default['kyamera_pro_testimonial_custom_name'] );
	        	        $position   = get_theme_mod( 'kyamera_pro_testimonial_position_' . $i );
	        	        $excerpt   = get_theme_mod( 'kyamera_pro_testimonial_custom_content_' . $i, $default['kyamera_pro_testimonial_custom_content'] );

	        	        $img_url = get_theme_mod( 'kyamera_pro_testimonial_image_' . $i );
	        	        $url = get_theme_mod( 'kyamera_pro_testimonial_custom_url_' . $i );
	        	        
	        	        $class = ( ! empty( $img_url ) ) ? 'has-featured-image' : '';

	        	        ?>
	        	        <article>
	        	        	<?php if (!empty($img_url)) : ?>
	                            <div class="featured-image" style="background-image: url('<?php echo esc_url($img_url); ?>');">
	                                <a href="<?php echo esc_url($url); ?>" class="post-thumbnail-link"></a>
	                            </div><!-- .featured-image -->
                        	<?php endif; ?>
                        	<?php if (!empty($excerpt)) : ?>
	                            <div class="entry-content">
	                                <?php echo wp_kses_post($excerpt); ?>
	                            </div><!-- .entry-content -->
	                        <?php endif; ?>
                            <header class="entry-header">
                            	<?php if (!empty($title)) : ?>
	                                <h2 class="entry-title"><a href="<?php echo esc_url($url); ?>"><?php echo esc_html($title); ?></a></h2>
	                            <?php endif; ?>
	                            <?php if (!empty($position)) : ?>
	                                <p class="position"><?php echo esc_html($position); ?></p>
	                            <?php endif; ?>
                            </header>
                    	</article>
	        	<?php   
	        	    }
	        	}
	        	?>
		</div><!-- .testimonial-slider -->
    </div><!-- .wrapper -->
</div><!-- #testimonial-section -->

