<?php
/**
 * Moral welcome page
 *
 * @package Moral
 */
add_action( 'admin_menu', 'kyamera_pro_welcome_menu' );

/**
 * Add admin submenu
 */
function kyamera_pro_welcome_menu() {
	add_theme_page( esc_html__( 'Kyamera Pro Options', 'kyamera-pro' ), esc_html__( 'About Kyamera Pro', 'kyamera-pro' ), 'manage_options', 'kyamera-welcome', 'kyamera_pro_welcome_display' );
}

/**
 * Welcome column loop
 * @param  array  $args [description]
 * @return string  Columns HTML
 */
function kyamera_pro_get_welcome_columns( $args = array() ) {
	foreach ( $args as $key => $value ) { 
		$target = '';
		if ( $value['new_tab'] ) {
			$target = "_blank";
		}
		?>
		<div class="column">
			<h2 class="kyamera-postbox-title <?php echo esc_attr( $key ); ?>"><span class="dashicons dashicons-<?php echo esc_attr( $value['icon'] );?>"></span><?php echo esc_html( $value['title'] ); ?></h2>
			<div class="kyamera-postbox-content">
				<p><?php echo esc_html( $value['desc'] ); ?></p>
				<a target="<?php echo esc_attr( $target ); ?>" class="button button-primary button-hero load-customize hide-if-no-customize" href="<?php echo esc_url( $value['url'] ); ?>"><?php echo esc_html( $value['btn_txt'] ); ?></a>
			</div><!-- .kyamera-box-content-->
		</div><!-- .column -->
	<?php
	}
}

/**
 * Display admin welcome page.
 */
function kyamera_pro_welcome_display() {
	if ( ! current_user_can( 'manage_options' ) )  {
		wp_die( esc_html__( 'You do not have sufficient permissions to access this page.', 'kyamera-pro' ) );
	}

	$theme_data = wp_get_theme();
	?>
	<div id="kyamera-themes-wrapper">
		<div id="kyamera-header-content">
			<h1><?php echo esc_html( $theme_data->get( 'Name' ) ) . esc_html__( '-', 'kyamera-pro' ) . esc_html( $theme_data->get( 'Version' ) ); ?></h1>
			<p><?php echo esc_html( $theme_data->get( 'Description' ) ); ?></p>
		</div><!-- #kyamera-header-content -->
		
		<div id="kyamera-postbox-container">
			<?php 
			$args = array(
				'live-demo' => array(
					'title' => esc_html__( 'View Demo', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Woohoo!!! Kyamera Pro has been installed. Now want to have a peek at how Kyamera Pro theme would look as set up by the author. Mind that the setup is one of the many usage of the theme, you can create a different setup of the same theme. Just click the button below.', 'kyamera-pro' ),
					'url' => 'https://demo.moralthemes.com/kyamera-pro/',
					'new_tab' => true,
					'icon' => 'external',
					'btn_txt' => esc_html__( 'View Demo', 'kyamera-pro' )
				),
				'demo-importer' => array(
					'title' => esc_html__( 'One Click Demo Import', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Liked the demo and want to setup just like the demo? Just import the content and start editing  the content right away. One Click Demo Importer should be installed before the importer works. You are just a click away.', 'kyamera-pro' ),
					'url' =>  menu_page_url( 'pt-one-click-demo-import', false ),
					'new_tab' => false,
					'icon' => 'upload',
					'btn_txt' => esc_html__( 'Import Demo Content', 'kyamera-pro' )
				),
				'documentation' => array(
					'title' => esc_html__( 'Documentation', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Still getting confused after import? Or wanna start without the demo content. Do not worry!!! Kyamera Pro Themes provide a detailed documentation about the theme, its setup and other extra tips and tricks.', 'kyamera-pro' ),
					'icon' => 'list-view',
					'url' => '',
					'new_tab' => true,
					'btn_txt' => esc_html__( 'View Documentation', 'kyamera-pro' )
				),
				'support' => array(
					'title' => esc_html__( 'Support', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Need any help regarding the theme? Got stuck somewhere? Kyamera Pro theme support is just a click away. Search our incredible and 24/7 support forum. Query your questions and your solution will be resolved by our strong and dedicated support teams.', 'kyamera-pro' ),
					'url' => '',
					'new_tab' => true,
					'icon' => 'admin-users',
					'btn_txt' => esc_html__( 'Support Forum', 'kyamera-pro' )
				),
				'theme-features' => array(
					'title' => esc_html__( 'Theme Features', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Kyamera Pro theme comes with some incredible features. The elite feature of the theme is the user experience, code and security. Want to know more about the key features of the theme?', 'kyamera-pro' ),
					'url' => '',
					'new_tab' => true,
					'icon' => 'tag',
					'btn_txt' => esc_html__( 'Theme Features', 'kyamera-pro' )
				),
				'theme-comparison' => array(
					'title' => esc_html__( 'Free vs Pro', 'kyamera-pro' ),
					'desc'	=> esc_html__( 'Want to enhance your site? The Pro version provides more of the elite features that will enhance your site. There is more to the Kyamera Pro than meets the eye.', 'kyamera-pro' ),
					'url' => '',
					'new_tab' => true,
					'icon' => 'star-half',
					'btn_txt' => esc_html__( 'Theme Comparison', 'kyamera-pro' )
				),
			);

			if ( ! class_exists( 'OCDI_Plugin' ) ) {
				$args['demo-importer']['url'] = menu_page_url( 'tgmpa-install-plugins', false );
				$args['demo-importer']['btn_txt'] = esc_html__( 'Install One Click Demo Import', 'kyamera-pro' );
			}

			kyamera_pro_get_welcome_columns( $args ); ?>

		</div><!-- .postbox-container -->
	</div><!-- .wrap -->
<?php
}